local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local _

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.Enemy, x.ActiveEnemy, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

a.StatBuffs = {
	1126--[[Mark of the Wild]],
	115921--[[Legacy of the Emperor]],
	20217--[[Blessing of Kings]],
	90363--[[Embrace of the Shale Spider]]
}

a.CritBuffs = {
	116781--[[Legacy of the White Tiger]],
	17007--[[Leader of the Pack]],
	1459--[[Arcane Brilliance]],
	61316--[[Dalaran Brilliance]],
	97229--[[Bellowing Roar]],
	24604--[[Furious Howl]],
	90309--[[Terrifying Roar]],
	126373--[[Fearless Roar]],
	126309--[[Still Water]],
}

a.spells["Auto Attack"] = {
	ID = 6603--[[Auto Attack]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	NotIfActive = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["Berserking"] = {
	ID = 26297--[[Berserking]],
	Buff = 26297--[[Berserking]],
	BuffUnit = "player",
	NoRangeCheck = true,
	Check = function(z)
		return x.InCombat and x.ActiveEnemy
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["Blood Fury"] = {
	ID = 20572--[[Blood Fury]],
	Buff = 20572--[[Blood Fury]],
	BuffUnit = "player",
	NoRangeCheck = true,
	Check = function(z)
		return x.InCombat and x.ActiveEnemy
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["Synapse Springs"] = {
	Type = "item",
	NoRangeCheck = true,
	Check = function(z)
		local gloves = GetInventoryItemID("player", 10)
		z.ID = gloves
		z.FlashID = gloves
		return x.InCombat and x.ActiveEnemy and s.ItemCooldown(gloves) <= s.GlobalCooldown()
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["Potion with Bloodlust or TTD <= 60"] = {
	Type = "item",
	ID = 76089--[[Virmen's Bite]],
	Buff = {105697--[[Virmen's Bite]], 79633--[[Potion of the Tol'vir]]},
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.ActiveEnemy and s.Boss("target")
	end,
	CheckLast = function(z)
		return x.Bloodlust or (x.TimeToDie <= 60)
	end,
	FlashID = {76089--[[Virmen's Bite]], 58145--[[Potion of the Tol'vir]]},
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["Purify Moderate Stagger"] = {
	ID = 119582--[[Purifying Brew]],
	NoGCD = true,
	FlashColor = "Yellow",
	ConsumeDebuff = 124274--[[Moderate Stagger]],
	ConsumeBuffUnit = "player", 
	Check = function(z)
		return x.Chi > 2 or x.ShuffleDuration > 6
	end,
}

a.spells["Purify Heavy Stagger"] = {
	ID = 119582--[[Purifying Brew]],
	NoGCD = true,
	FlashColor = "Red",
	ConsumeDebuff = 124273--[[Heavy Stagger]],
	ConsumeBuffUnit = "player", 
}

a.spells["Healing Elixiers"] = {
	ID = 119582--[[Purifying Brew]],
	NoGCD = true,
	FlashColor = "Yellow",
	ConsumeBuff = 134563--[[Healing Elixiers]],
	ConsumeBuffUnit = "player", 
	Check = function(z)
		return s.HealthPercent("player") < 85
	end,
}

a.spells["Rushing Jade Wind (AoE, Brewmaster)"] = {
	ID = 116847--[[Rushing Jade Wind]],
	Buff = 115307--[[Shuffle]],
	BuffUnit = "player",
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	Check = function(z)
		if s.Boss("target") then
			z.EarlyRefresh = 6
		else
			z.EarlyRefresh = 3
		end
		return x.NoCC and x.AoE
	end,
}

a.spells["Rushing Jade Wind (Range, Brewmaster)"] = {
	ID = 116847--[[Rushing Jade Wind]],
	Buff = 115307--[[Shuffle]],
	BuffUnit = "player",
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	Check = function(z)
		if s.Boss("target") then
			z.EarlyRefresh = 6
		else
			z.EarlyRefresh = 3
		end
		return x.NoCC and not s.MeleeDistance("target")
	end,
}

a.spells["Blackout Kick (Brewmaster)"] = {
	ID = 100784--[[Blackout Kick]],
	Buff = 115307--[[Shuffle]],
	BuffUnit = "player",
	EnemyTargetNeeded = true,
	Check = function(z)
		if s.Boss("target") then
			z.EarlyRefresh = 6
		else
			z.EarlyRefresh = 3
		end
		return x.NoCC
	end,
}

a.spells["BoK at full Chi"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.NoCC and x.Chi == x.MaxChi
	end,
}

a.spells["BoK to avoid capping"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.NoCC and x.Chi > x.MaxChi - 2
	end,
}

a.spells["Nimble Brew"] = {
	ID = 137562--[[Nimble Brew]],
	NoRangeCheck = true,
	NoGCD = true,
	FlashBlink = true,
	Check = function(z)
		local eventIndex = C_LossOfControl.GetNumEvents()
		while (eventIndex > 0) do
			local locType, _, _, _, _, timeRemaining = C_LossOfControl.GetEventInfo(eventIndex)
			if locType == "ROOT" or locType == "STUN_MECHANIC" or locType == "FEAR" then
				return timeRemaining > 1.5
			end
			eventIndex = eventIndex - 1
		end
	end,
}

a.spells["Tiger's Lust"] = {
	ID = 116841--[[Tiger's Lust]],
	NoRangeCheck = true,
	Check = function(z)
		return s.HasTalent(116841--[[Tiger's Lust]]) and s.MovementImpaired("player", 1, false, true) == 1
	end,
}

a.spells["Chi Wave w/ time to max energy > 2"] = {
	ID = 115098--[[Chi Wave]],
	Check = function(z)
		return s.HasTalent(115098--[[Chi Wave]]) and x.TimeToMax > 2
	end,
}

a.spells["Chi Wave"] = {
	ID = 115098--[[Chi Wave]],
	Check = function(z)
		return s.HasTalent(115098--[[Chi Wave]])
	end,
}

a.spells["Zen Sphere"] = {
	ID = 124081--[[Zen Sphere]],
	Buff = 124081--[[Zen Sphere]],
	BuffUnit = "player",
	NoRangeCheck = true,
	Unit = "player",
	Check = function(z)
		return x.ShouldTemporaryBuff and s.HasTalent(124081--[[Zen Sphere]])
	end,
}

a.spells["Chi Burst"] = {
	ID = 123986--[[Chi Burst]],
	Check = function(z)
		return s.HasTalent(123986--[[Chi Burst]])
	end,
	NotWhileMoving = true,
}

a.spells["Chi Brew"] = {
	ID = 115399--[[Chi Brew]],
	NoRangeCheck = true,
	Check = function(z)
		return s.HasTalent(115399--[[Chi Brew]]) and x.Chi == 0
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["Charging Ox Wave"] = {
	ID = 119392--[[Charging Ox Wave]],
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	Check = function(z)
		return s.HasTalent(119392--[[Charging Ox Wave]]) and not s.MeleeDistance("target")
	end,
	FlashColor = "Pink",
}

a.spells["Dampen Harm"] = {
	ID = 122278--[[Dampen Harm]],
	Check = function(z)
		return s.HasTalent(122278--[[Dampen Harm]]) and s.HealthPercent("player") < 50 and x.ShouldTemporaryBuff and x.InCombat
	end,
	FlashColor = "Red",
}

a.spells["Diffuse Magic"] = {
	ID = 122783--[[Diffuse Magic]],
	Check = function(z)
		return s.HasTalent(122783--[[Diffuse Magic]]) and s.HealthPercent("player") < 50 and x.ShouldTemporaryBuff and x.InCombat
	end,
	FlashColor = "Red",
}

a.spells["Rushing Jade Wind"] = {
	ID = 116847--[[Rushing Jade Wind]],
	NoRangeCheck = true,
	Check = function(z)
		if x.AoE then
			z.FlashColor = "White"
			z.Continue = false
		else
			z.FlashColor = "Purple"
			z.Continue = true
		end
		return x.NoCC and s.HasTalent(116847--[[Rushing Jade Wind]])
	end,
}

a.spells["Invoke Xuen, the White Tiger"] = {
	ID = 123904--[[Invoke Xuen, the White Tiger]],
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.NoCC and s.HasTalent(123904--[[Invoke Xuen, the White Tiger]]) and x.InCombat
	end,
	Continue = true,
	FlashColor = "Purple",
}

a.spells["Breath of Fire"] = {
	ID = 115181--[[Breath of Fire]],
	MyDebuff = 115181--[[Breath of Fire]],
	RequireDebuff = 115180--[[Dizzying Haze]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.NoCC and x.AoE
	end,
}

a.spells["Rising Sun Kick (Debuff)"] = {
	ID = 107428--[[Rising Sun Kick]],
	MyDebuff = 130320--[[Rising Sun Kick]],
	EarlyRefresh = 3,
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC
	end,
}

a.spells["Rising Sun Kick"] = {
	ID = 107428--[[Rising Sun Kick]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC
	end,
}

a.spells["Rising Sun Kick at 4+ Chi"] = {
	ID = 107428--[[Rising Sun Kick]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.Chi >= 4
	end,
}

a.spells["Fists of Fury"] = {
	ID = 113656--[[Fists of Fury]],
	EnemyTargetNeeded = true,
	Melee = true,
	NoRangeCheck = true,
	NotWhileMoving = true,
	Check = function(z)
		return x.NoCC and not s.Buff(115288--[[Energizing Brew]], "player") and x.TimeToMax > 4 and s.BuffDuration(125359--[[Tiger Power]], "player") > 4
	end,
}

a.spells["Energizing Brew"] = {
	ID = 115288--[[Energizing Brew]],
	Buff = 115288--[[Energizing Brew]],
	BuffUnit = "player",
	Check = function(z)
		return x.ShouldTemporaryBuff and x.InCombat and x.TimeToMax > 5
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["Spinning Crane Kick (Brewmaster)"] = {
	ID = 101546--[[Spinning Crane Kick]],
	Check = function(z)
		return x.AoE and s.SpellCooldown(121253--[[Keg Smash]]) > 1
	end,
}

a.spells["Spinning Crane Kick (WW)"] = {
	ID = 101546--[[Spinning Crane Kick]],
	Check = function(z)
		return x.NoCC
	end,
}

a.spells["Keg Smash"] = {
	ID = 121253--[[Keg Smash]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.Chi <= (x.MaxChi - 2)
	end,
}

a.spells["Expel Harm (Brewmaster)"] = {
	ID = 115072--[[Expel Harm]],
	EnemyTargetNeeded = false,
	Check = function(z)
		return s.HealthPercent("player") < 80
	end,
}

a.spells["Expel Harm (Windwalker)"] = {
	ID = 115072--[[Expel Harm]],
	EnemyTargetNeeded = false,
	Check = function(z)
		return s.HealthPercent("player") < 80 and x.Chi <= (x.MaxChi - 2) 
	end,
	Continue = true,
}

a.spells["Flying Serpent Kick"] = {
	ID = 101545--[[Flying Serpent Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return not s.MeleeDistance("target")
	end,
	FlashColor = "Pink",
}

a.spells["Jab (Brewmaster)"] = {
	ID = 100780--[[Jab]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.Chi <= (x.MaxChi - s.If(s.Buff(129914--[[Power Strikes]], "player"), 2, 1)) and x.Energy + s.SpellCooldown(121253--[[Keg Smash]]) * x.EnergyPerSecond > 80
	end,
	FlashID = {100780, 115698, 108967, 130257, 108557, 115687, 115693, 115695, 125661},
}

a.spells["Jab (Windwalker)"] = {
	ID = 100780--[[Jab]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.Chi <= (x.MaxChi - s.If(s.Buff(129914--[[Power Strikes]], "player"), 3, 2)) and x.Energy >= 40
	end,
	FlashID = {100780, 115698, 108967, 130257, 108557, 115687, 115693, 115695, 125661},
}

a.spells["Guard"] = {
	ID = 115295--[[Guard]],
	Buff = 123402--[[Guard]],
	BuffUnit = "player",
	ConsumeBuff = 118636--[[Power Guard]],
	ConsumeBuffUnit = "player", 
	NoGCD = true,
	FlashColor = "Yellow",
	Check = function(z)
		return x.Chi >= 3
	end,
}

a.spells["Tiger Palm Buff (Brewmaster)"] = {
	ID = 100787--[[Tiger Palm]],
	Buff = 125359--[[Tiger Power]],
	BuffUnit = "player",
	EarlyRefresh = 3,
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.ShuffleDuration > 1
	end,
}

a.spells["Tiger Palm (Brewmaster)"] = {
	ID = 100787--[[Tiger Palm]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.ShuffleDuration > 1
	end,
}

a.spells["Combo Breaker: Tiger Palm"] = {
	ID = 100787--[[Tiger Palm]],
	ConsumeBuff =  118864--[[Combo Breaker: Tiger Palm]],
	ConsumeBuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	NoPowerCheck = true,
	EvenIfNotUsable = true,
	Check = function(z)
		return x.NoCC and (x.TimeToMax >= 2 or s.BuffDuration(118864--[[Combo Breaker: Tiger Palm]], "player") <= 2)
	end,
}

a.spells["Combo Breaker: Blackout Kick"] = {
	ID = 100784--[[Blackout Kick]],
	ConsumeBuff =  116768--[[Combo Breaker: Blackout Kick]],
	ConsumeBuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	NoPowerCheck = true,
	EvenIfNotUsable = true,
	Check = function(z)
		return x.NoCC
	end,
}

a.spells["Blackout Kick w/o disturbing RSK"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and (x.Energy + (x.EnergyPerSecond * s.SpellCooldown(107428--[[Rising Sun Kick]]))) >= 40
	end,
}

a.spells["Tigereye Brew"] = {
	ID = 116740--[[Tigereye Brew]],
	ConsumeBuff = 125195--[[Tigereye Brew]],
	ConsumeBuffUnit = "player",
	ConsumeStack = 10,
	NoGCD = true,
	FlashColor = "Yellow",
	Check = function(z)
		return x.ShouldTemporaryBuff and s.SpellCooldown(107428--[[Rising Sun Kick]]) <= s.GlobalCooldown() and x.Chi >=2 and s.Buff(125359--[[Tiger Power]], "player")
	end,
}

a.spells["Tiger Palm w/ Tiger Power <= 3"] = {
	ID = 100787--[[Tiger Palm]],
	Buff = 125359--[[Tiger Power]],
	BuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	EarlyRefresh = 3,
	Check = function(z)
		return x.NoCC and x.Chi >= 2 and s.Buff(125359--[[Tiger Power]], "player")
	end,
}

a.spells["Tiger Palm w/o Tiger Power"] = {
	ID = 100787--[[Tiger Palm]],
	Buff = 125359--[[Tiger Power]],
	BuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.Chi >= 2 and not s.Buff(125359--[[Tiger Power]], "player") and s.DebuffDuration(130320--[[Rising Sun Kick]], "target") > 1 and x.TimeToMax > 1
	end,
}

a.spells["Elusive Brew"] = {
	ID = 115308--[[Elusive Brew]],
	Buff = 115308--[[Elusive Brew]],
	BuffUnit = "player",
	UseBuffID = true,
	ConsumeBuff = 128939--[[Elusive Brew]],
	ConsumeBuffUnit = "player",
	ConsumeUseBuffID = true,
	ConsumeStack = 9,
	Check = function(z)
		z.FlashBlink = false
		if x.ThreatPercent < 100 then
			z.FlashColor = "Pink"
		else
			z.FlashColor = "Yellow"
			if s.BuffStack(128939--[[Elusive Brew]], "player") == 15 then
				z.FlashBlink = true
			end
		end
		return x.InCombat
	end,
	NoGCD = true,
}

a.spells["Fortifying Brew"] = {
	ID = 115203--[[Fortifying Brew]],
	Buff = 120954--[[Fortifying Brew]],
	BuffUnit = "player",
	FlashColor = "Red",
	Check = function(z)
		return s.HealthPercent("player") < 50 and x.InCombat
	end,
	NoGCD = true,
}

a.spells["Stance of the Sturdy Ox"] = {
	Type = "form",
	ID = 115069--[[Stance of the Sturdy Ox]],
	Buff = 115069--[[Stance of the Sturdy Ox]],
	BuffUnit = "player",
	FlashColor = "Green",
}

a.spells["Stance of the Fierce Tiger"] = {
	Type = "form",
	ID = 103985--[[Stance of the Fierce Tiger]],
	Buff = 103985--[[Stance of the Fierce Tiger]],
	BuffUnit = "player",
	FlashColor = "Green",
}

a.spells["Stance of the Wise Serpent"] = {
	Type = "form",
	ID = 115070--[[Stance of the Wise Serpent]],
	Buff = 115070--[[Stance of the Wise Serpent]],
	BuffUnit = "player",
	FlashColor = "Green",
}

a.spells["Legacy of the Emperor"] = {
	ID = 115921--[[Legacy of the Emperor]],
	Buff = a.StatBuffs,
	EarlyRefresh = 10,
	NoRangeCheck = true,
	BuffUnit = "raid",
	FlashColor = "Green",
}

a.spells["Legacy of the White Tiger"] = {
	ID = 116781--[[Legacy of the White Tiger]],
	Buff = a.CritBuffs,
	EarlyRefresh = 10,
	NoRangeCheck = true,
	BuffUnit = "raid",
	FlashColor = "Green",
}

a.spells["Spear Hand Strike"] = {
	ID = 116705--[[Spear Hand Strike]],
	EnemyTargetNeeded = true,
	Interrupt = true,
	NoGCD = true,
	FlashColor = "Aqua",
}

a.spells["Paralysis"] = {
	ID = 115078--[[Paralysis]],
	EnemyTargetNeeded = true,
	Interrupt = 1,
	Check = function(z)
		return not s.Boss("target")
	end,
	FlashColor = "Aqua",
}

a.spells["Leg Sweep as Interrupt"] = {
	ID = 119381--[[Leg Sweep]],
	EnemyTargetNeeded = true,
	Interrupt = 1,
	Check = function(z)
		return s.HasTalent(119381--[[Leg Sweep]]) and not s.Boss("target")
	end,
	FlashColor = "Aqua",
}

a.spells["Leg Sweep in AoE"] = {
	ID = 119381--[[Leg Sweep]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.AoE and s.HasTalent(119381--[[Leg Sweep]]) and not s.Boss("target")
	end,
	Continue = true,
}

a.spells["Provoke"] = {
	ID = 115546--[[Provoke]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return s.Form(115069--[[Stance of the Sturdy Ox]]) and x.NoCC and x.ThreatPercent <= 99 and ( GetNumGroupMembers() > 1 or GetNumSubgroupMembers() > 0 ) and x.InCombat
	end,
	NoGCD = true,
	FlashColor = "Purple",
}

a.spells["Clash"] = {
	ID = 122057--[[Clash]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.NoCC and not s.MeleeDistance("target")
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["Roll"] = {
	ID = 109132--[[Roll]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return not s.MeleeDistance("target")
	end,
	NoGCD = true,
	FlashColor = "Pink",
}

a.spells["Dizzying Haze"] = {
	ID = 115180--[[Dizzying Haze]],
	Debuff = 115180--[[Dizzying Haze]],
	EnemyTargetNeeded = true,
	NoRangeCheck = true,
	FlashColor = "Blue",
}